EXPORTS
	?ContinueWithNewOutputFileL@CRefTestAgentImport@ReferenceTestAgent@@QAEXAAVRFile@@ABVTDesC16@@@Z @ 1 NONAME ; void ReferenceTestAgent::CRefTestAgentImport::ContinueWithNewOutputFileL(class RFile &, class TDesC16 const &)
	?CreateArchive@CRefTestAgentArchive@ReferenceTestAgent@@SAHABVTDesC16@@0AAVTDes16@@AAVTDes8@@@Z @ 2 NONAME ; int ReferenceTestAgent::CRefTestAgentArchive::CreateArchive(class TDesC16 const &, class TDesC16 const &, class TDes16 &, class TDes8 &)
	?DefaultMimeType@CRefTestAgentArchive@ReferenceTestAgent@@QAEABVTDesC8@@XZ @ 3 NONAME ; class TDesC8 const & ReferenceTestAgent::CRefTestAgentArchive::DefaultMimeType(void)
	?DrmFilesL@CRefTestAgentArchive@ReferenceTestAgent@@QAEAAVCDrmFiles@2@XZ @ 4 NONAME ; class ReferenceTestAgent::CDrmFiles & ReferenceTestAgent::CRefTestAgentArchive::DrmFilesL(void)
	?GetDefaultMimeTypeFromHeaderL@CRefTestAgentArchive@ReferenceTestAgent@@SAXABVTDesC8@@AAVTDes8@@@Z @ 5 NONAME ; void ReferenceTestAgent::CRefTestAgentArchive::GetDefaultMimeTypeFromHeaderL(class TDesC8 const &, class TDes8 &)
	?GetSuggestedOutputFileExtension@CRefTestAgentImport@ReferenceTestAgent@@QAEHAAVTDes16@@@Z @ 6 NONAME ; int ReferenceTestAgent::CRefTestAgentImport::GetSuggestedOutputFileExtension(class TDes16 &)
	?GetSuggestedOutputFileName@CRefTestAgentImport@ReferenceTestAgent@@QAEHAAVTDes16@@@Z @ 7 NONAME ; int ReferenceTestAgent::CRefTestAgentImport::GetSuggestedOutputFileName(class TDes16 &)
	?NewL@CRefTestAgentArchive@ReferenceTestAgent@@SAPAV12@AAVRFile64@@@Z @ 8 NONAME ; class ReferenceTestAgent::CRefTestAgentArchive * ReferenceTestAgent::CRefTestAgentArchive::NewL(class RFile64 &)
	?NewL@CRefTestAgentImport@ReferenceTestAgent@@SAPAV12@ABVTDesC16@@AAVRFs@@ABW4TImportFileMimeType@2@@Z @ 9 NONAME ; class ReferenceTestAgent::CRefTestAgentImport * ReferenceTestAgent::CRefTestAgentImport::NewL(class TDesC16 const &, class RFs &, enum ReferenceTestAgent::TImportFileMimeType const &)
	?WriteComplete@CRefTestAgentImport@ReferenceTestAgent@@QAEHXZ @ 10 NONAME ; int ReferenceTestAgent::CRefTestAgentImport::WriteComplete(void)
	?WriteL@CRefTestAgentImport@ReferenceTestAgent@@QAEXABVTDesC8@@@Z @ 11 NONAME ; void ReferenceTestAgent::CRefTestAgentImport::WriteL(class TDesC8 const &)
	?SetMetaDataL@CRefTestAgentImport@ReferenceTestAgent@@QAEXABVCMetaDataArray@ContentAccess@@@Z @ 12 NONAME ; void ReferenceTestAgent::CRefTestAgentImport::SetMetaDataL(class ContentAccess::CMetaDataArray const &)
	?GetCurrentFileNameAndBuffer@CRefTestAgentImport@ReferenceTestAgent@@QAEXAAVTDes16@@AAVTDes8@@@Z @ 13 NONAME ; void ReferenceTestAgent::CRefTestAgentImport::GetCurrentFileNameAndBuffer(class TDes16 &, class TDes8 &)

